@@ -35,7 +35,7 @@ evalNames skipEdTrans ns nl d
     , sa == "editor" && sb == "translator" ||
       sb == "editor" && sa == "translator" = do
         aa <- getAgents' sa
-        ab <- getAgents' sa
+        ab <- getAgents' sb
         if aa == ab
            then modify (\s -> s { edtrans = True }) >>
                 evalNames True [sa] nl d
