@@ -135,5 +135,5 @@ rtfParser fm s
                            ,parseQ "&apos;" "&apos;"
                            ]
       parseQ a b = try $ do
-        q <- string a >> manyTill anyChar (try $ string b)
+        q <- string a >> manyTill anyChar (try $ string b >> notFollowedBy letter)
         return [Output (rtfParser emptyFormatting q) (emptyFormatting {quotes = True})]
