@@ -20,6 +20,7 @@ import Control.Monad.State
 import Data.Generics
 import Data.Char (toLower, toUpper)
 import Data.List
+import qualified Data.Map as M
 import Data.Ratio
 
 import Text.JSON.Generic
@@ -50,6 +51,15 @@ readJsonString =
   let rmCom = unlines . filter (\x -> not (" *" `isPrefixOf` x || "/*" `isPrefixOf` x)) . lines
   in  either error id . runGetJSON readJSTopType . rmCom
 
+readJsonAbbrevFile :: FilePath -> IO [Abbrev]
+readJsonAbbrevFile f = readJsonAbbrev `fmap` readJsonFile f
+
+readJsonAbbrev :: JSValue -> [Abbrev]
+readJsonAbbrev
+    = mapSndObj (mapSndObj (M.fromList . mapSndObj fromJString))
+    where
+      mapSndObj f = map (second f) . fromObj
+
 readJsonCitations :: JSValue -> [Cite]
 readJsonCitations jv
     | JSArray (JSObject o:_) <- jv
@@ -91,8 +101,9 @@ editJsonInput (s,j)
     | "non-dropping-particle" <- s = ("nonDroppingPart", j)
     | "comma-suffix"          <- s = ("commaSuffix", toJSBool j)
     | "id"                    <- s = ("refId"      , toString j)
+    | "shortTitle"            <- s = ("titleShort" , j)
     | isRefDate s
-    , JSObject js <- j = (s            , JSArray (editDate $ fromJSObject js))
+    , JSObject js <- j = (camel s      , JSArray (editDate $ fromJSObject js))
     | "family"    <- s = ("familyName" , j)
     | "suffix"    <- s = ("nameSuffix" , j)
     | "edition"   <- s = ("edition"    , toString j)
@@ -111,7 +122,7 @@ editJsonInput (s,j)
       camel x
           | '-':y:ys <- x = toUpper y : camel ys
           | '_':y:ys <- x = toUpper y : camel ys
-          |     y:ys <- x =         y : camel ys
+          |     y:ys <- x = toLower y : camel ys
           | otherwise     = []
 
       format (x:xs) = toUpper x : xs
@@ -213,6 +224,11 @@ fromObj :: JSValue -> [(String, JSValue)]
 fromObj (JSObject o) = fromJSObject o
 fromObj _            = []
 
+fromJString :: JSValue -> String
+fromJString j
+    | JSString x <- j = fromJSString x
+    | otherwise       = []
+
 defaultJson :: [(String, JSValue)]
 defaultJson = fromObj (toJSON emptyReference) ++ fromObj emptyRefDate ++
               fromObj emptyPerson ++ fromObj emptyCite'
