@@ -72,7 +72,7 @@ render sty fo
           | otherwise                       = i
 
       toPandoc f i = addSuffix f $ toStr (prefix f) ++
-                     (format f . quote f . proc cleanStrict $ i)
+                     (quote f . format f . proc cleanStrict $ i)
       format     f = font_variant f . font f . text_case f
       rest      xs = procList xs $ concatMap (render sty)
       quote    f i = if i /= [] && quotes f
@@ -305,7 +305,7 @@ mapHeadInline f (i:xs)
     | SmallCaps   is <- i = SmallCaps   (mapHeadInline f is)   : xs
     | Strikeout   is <- i = Strikeout   (mapHeadInline f is)   : xs
     | Link      is t <- i = Link        (mapHeadInline f is) t : xs
-    | otherwise           = []
+    | otherwise           = i : xs
 
 getInline :: Inline -> [Inline]
 getInline i
