@@ -22,7 +22,7 @@ import Text.CSL.Style
 import Text.CSL.Pickle
 #ifdef EMBED_DATA_FILES
 import Data.FileEmbed
-import qualified Data.ByteString as BS
+import qualified Data.ByteString as S
 import Data.ByteString.UTF8 ( toString )
 #else
 import Paths_citeproc_hs ( getDataFileName )
@@ -31,6 +31,8 @@ import System.Directory  ( doesFileExist   )
 
 import Data.Char        ( isUpper, toUpper, toLower )
 import Data.Maybe       ( catMaybes                 )
+import qualified Data.ByteString.Lazy as L
+import Data.ByteString.Lazy.UTF8 ( fromString )
 
 #ifdef USE_NETWORK
 import Network.HTTP ( getResponseBody, mkRequest, RequestMethod(..) )
@@ -48,19 +50,26 @@ readCSLFile src = do
                               setUserAgent "citeproc-hs"
                               request $ mkRequest GET u
                      getResponseBody (Right $ snd rsp)
-  s <- case parseURI src of
-         Just u | uriScheme u `elem` ["http:","https:"] ->
-                    readURI u >>= return . readXmlString xpStyle
-         _       -> readXmlFile xpStyle src
+  f <- case parseURI src of
+         Just u | uriScheme u `elem` ["http:","https:"] -> readURI u
+         _                                              -> readFile' src
 #else
-  s <- readXmlFile xpStyle src
+  f <- readFile' src
 #endif
+  parseCSL' f
+
+-- | Parse a 'String' into a fully localized 'Style'
+parseCSL :: String -> IO Style
+parseCSL = parseCSL' . fromString
+
+parseCSL' :: L.ByteString -> IO Style
+parseCSL' f = do
+  let s = readXmlString xpStyle f
   l <- readLocaleFile (styleDefaultLocale s)
   return s { styleLocale = mergeLocales (styleDefaultLocale s) l (styleLocale s)}
 
-
 #ifdef EMBED_DATA_FILES
-localeFiles :: [(FilePath, BS.ByteString)]
+localeFiles :: [(FilePath, L.ByteString)]
 localeFiles = $(embedDir "locales/")
 #endif
 
@@ -69,7 +78,7 @@ readLocaleFile s = do
 #ifdef EMBED_DATA_FILES
   f <- case s of
          x | length x == 2 -> let fn = ("locales-" ++
-                                        maybe (error $ x ++ " doesn't seem a valid locale")
+                                        maybe "en-US"
                                         id (lookup x langBase) ++ ".xml")
                               in case lookup fn localeFiles of
                                    Just x' -> return x'
@@ -77,11 +86,11 @@ readLocaleFile s = do
             | otherwise     -> case lookup ("locales-" ++ take 5 x ++ ".xml") localeFiles of
                                  Just x' -> return x'
                                  _       -> error "could not load the locale file"
-  return $ readXmlString xpLocale (toString f)
+  return $ readXmlString xpLocale f
 #else
   f <- case s of
          x | length x == 2 -> getDataFileName ("locales/locales-" ++
-                                               maybe (error $ x ++ " doesn't seem a valid locale")
+                                               maybe "en-US"
                                                id (lookup x langBase) ++ ".xml")
            | otherwise     -> getDataFileName ("locales/locales-" ++ take 5 x ++ ".xml")
   b <- doesFileExist f
@@ -506,7 +515,7 @@ xpLocaleDate :: PU Element
 xpLocaleDate
     = xpWrap ( \((s,f,fm),(d,dp,dp'))    -> Date (words s) f fm d dp dp'
              , \(Date s f fm d dp dp') -> ((unwords s,f,fm),(d,dp,dp'))) $
-      xpElem  "date" $
+      xpIElem  "date" $
       xpPair  (xpTriple (xpLift []) xpickle xpickle)
               (xpTriple xpDelimiter xpickle (xpLift []))
 
