@@ -92,6 +92,7 @@ data RefType
     | Book
     | Broadcast
     | Chapter
+    | Dataset
     | Entry
     | EntryDictionary
     | EntryEncyclopedia
@@ -137,19 +138,23 @@ data Reference =
     , recipient           :: [Agent]
     , interviewer         :: [Agent]
     , composer            :: [Agent]
+    , illustrator         :: [Agent]
     , originalAuthor      :: [Agent]
     , containerAuthor     :: [Agent]
     , collectionEditor    :: [Agent]
     , editorialDirector   :: [Agent]
+    , reviewedAuthor      :: [Agent]
 
     , issued              :: [RefDate]
     , eventDate           :: [RefDate]
     , accessed            :: [RefDate]
     , container           :: [RefDate]
     , originalDate        :: [RefDate]
+    , submitted           :: [RefDate]
 
     , title               :: String
     , titleShort          :: String
+    , reviewedTitle       :: String
     , containerTitle      :: String
     , collectionTitle     :: String
     , containerTitleShort :: String
@@ -158,7 +163,9 @@ data Reference =
     , publisher           :: String
     , originalPublisher   :: String
     , publisherPlace      :: String
+    , originalPublisherPlace :: String
     , authority           :: String
+    , jurisdiction        :: String
     , archive             :: String
     , archivePlace        :: String
     , archiveLocation     :: String
@@ -176,6 +183,7 @@ data Reference =
     , status              :: String
     , edition             :: String
     , section             :: String
+    , source              :: String
     , genre               :: String
     , note                :: String
     , annote              :: String
@@ -186,6 +194,12 @@ data Reference =
     , url                 :: String
     , doi                 :: String
     , isbn                :: String
+    , issn                :: String
+    , pmcid               :: String
+    , pmid                :: String
+    , callNumber          :: String
+    , dimensions          :: String
+    , scale               :: String
     , categories          :: [String]
 
     , citationNumber           :: CNum
@@ -205,29 +219,34 @@ emptyReference =
     , recipient           = []
     , interviewer         = []
     , composer            = []
+    , illustrator         = []
     , originalAuthor      = []
     , containerAuthor     = []
     , collectionEditor    = []
     , editorialDirector   = []
+    , reviewedAuthor      = []
 
     , issued              = []
     , eventDate           = []
     , accessed            = []
     , container           = []
     , originalDate        = []
+    , submitted           = []
 
     , title               = []
     , titleShort          = []
+    , reviewedTitle       = []
     , containerTitle      = []
-    , containerTitleShort = []
     , collectionTitle     = []
-
+    , containerTitleShort = []
     , collectionNumber    = []
     , originalTitle       = []
     , publisher           = []
     , originalPublisher   = []
     , publisherPlace      = []
+    , originalPublisherPlace = []
     , authority           = []
+    , jurisdiction        = []
     , archive             = []
     , archivePlace        = []
     , archiveLocation     = []
@@ -245,6 +264,7 @@ emptyReference =
     , status              = []
     , edition             = []
     , section             = []
+    , source              = []
     , genre               = []
     , note                = []
     , annote              = []
@@ -255,6 +275,12 @@ emptyReference =
     , url                 = []
     , doi                 = []
     , isbn                = []
+    , issn                = []
+    , pmcid               = []
+    , pmid                = []
+    , callNumber          = []
+    , dimensions          = []
+    , scale               = []
     , categories          = []
 
     , citationNumber           = CNum 0
