@@ -35,7 +35,7 @@ data Style
       , csMacros           :: [MacroMap]
       , citation           ::  Citation
       , biblio             ::  Maybe Bibliography
-      } deriving ( Show, Typeable, Data )
+      } deriving ( Show, Read, Typeable, Data )
 
 data Locale
     = Locale
@@ -44,7 +44,7 @@ data Locale
       , localeOptions :: [Option]
       , localeTermMap :: [TermMap]
       , localeDate    :: [Element]
-      } deriving ( Show, Eq, Typeable, Data )
+      } deriving ( Show, Read, Eq, Typeable, Data )
 
 -- | With the 'defaultLocale', the locales-xx-XX.xml loaded file and
 -- the parsed 'Style' cs:locale elements, produce the final 'Locale'
@@ -79,14 +79,14 @@ data Citation
       { citOptions :: [Option]
       , citSort    :: [Sort]
       , citLayout  ::  Layout
-      } deriving ( Show, Typeable, Data )
+      } deriving ( Show, Read, Typeable, Data )
 
 data Bibliography
     = Bibliography
       { bibOptions :: [Option]
       , bibSort    :: [Sort]
       , bibLayout  ::  Layout
-      } deriving ( Show, Typeable, Data )
+      } deriving ( Show, Read, Typeable, Data )
 
 type Option = (String,String)
 
@@ -98,7 +98,7 @@ data Layout
       { layFormat ::  Formatting
       , layDelim  ::  Delimiter
       , elements  :: [Element]
-      } deriving ( Show, Typeable, Data )
+      } deriving ( Show, Read, Typeable, Data )
 
 data Element
     = Choose       IfThen    [IfThen]    [Element]
@@ -113,11 +113,11 @@ data Element
     | Substitute  [Element]
     | Group        Formatting Delimiter  [Element]
     | Date        [String]    DateForm    Formatting Delimiter [DatePart] String
-      deriving ( Show, Eq, Typeable, Data )
+      deriving ( Show, Read, Eq, Typeable, Data )
 
 data IfThen
     = IfThen Condition Match [Element]
-      deriving ( Eq, Show, Typeable, Data )
+      deriving ( Eq, Show, Read, Typeable, Data )
 
 data Condition
     = Condition
@@ -128,7 +128,7 @@ data Condition
       , isPosition      :: [String]
       , disambiguation  :: [String]
       , isLocator       :: [String]
-      } deriving ( Eq, Show, Typeable, Data )
+      } deriving ( Eq, Show, Read, Typeable, Data )
 
 type Delimiter = String
 
@@ -149,7 +149,7 @@ data DatePart
       , dpForm       :: String
       , dpRangeDelim :: String
       , dpFormatting :: Formatting
-      } deriving ( Show, Eq, Typeable, Data )
+      } deriving ( Show, Read, Eq, Typeable, Data )
 
 defaultDate :: [DatePart]
 defaultDate
@@ -160,7 +160,7 @@ defaultDate
 data Sort
     = SortVariable String Sorting
     | SortMacro    String Sorting Int Int String
-      deriving ( Eq, Show, Typeable, Data )
+      deriving ( Eq, Show, Read, Typeable, Data )
 
 data Sorting
     = Ascending  String
@@ -219,13 +219,13 @@ data Name
     = Name      Form Formatting NameAttrs Delimiter [NamePart]
     | NameLabel Form Formatting Plural
     | EtAl           Formatting String
-      deriving ( Eq, Show, Typeable, Data )
+      deriving ( Eq, Show, Read, Typeable, Data )
 
 type NameAttrs = [(String, String)]
 
 data NamePart
     = NamePart String Formatting
-      deriving ( Show, Eq, Typeable, Data )
+      deriving ( Show, Read, Eq, Typeable, Data )
 
 isPlural :: Plural -> Int -> Bool
 isPlural p l
