@@ -23,6 +23,7 @@ module Text.CSL.Test
 
 import Control.Arrow
 import Control.Monad.State
+import Data.ByteString.Lazy.UTF8 ( fromString )
 import Data.Char (toLower)
 import Data.List
 import Data.Maybe (isJust)
@@ -44,7 +45,7 @@ import Text.CSL.Proc
 import Text.CSL.Style
 import Text.Pandoc.Definition
 #ifdef EMBED_DATA_FILES
-import qualified Data.ByteString.UTF8 as BS ( toString )
+import Data.ByteString.UTF8 ( toString )
 import Text.CSL.Parser ( localeFiles )
 #else
 import System.IO.Unsafe
@@ -79,7 +80,7 @@ toTest ob = Test mode input style abbrevs result bibsection cites cites'
       look s = case lookup s object of
                  Just (JSString x) -> fromJSString x
                  _                 -> error $ "in test " ++ s ++ " section."
-      style  = readXmlString xpStyle $ look "csl"
+      style  = readXmlString xpStyle . fromString $ look "csl"
       mode   = look "mode"
       result = look "result"
 
@@ -211,12 +212,12 @@ putCachedLocale n t = modifyIORef localeCache $ \l -> (n, t) : l
 runTest :: Test -> IO (Bool,String)
 runTest t = do
   let locale = case styleDefaultLocale $ testCSL t of
-                 x | length x == 2 -> maybe (error $ x ++ " doesn't seem a valid locale")
+                 x | length x == 2 -> maybe "en-US"
                                       id (lookup x langBase)
                    | otherwise     -> take 5 x
 #ifdef EMBED_DATA_FILES
   ls <- case lookup ("locales-" ++ locale ++ ".xml") localeFiles of
-          Just x' -> return $ readXmlString xpLocale (BS.toString x')
+          Just x' -> return $ readXmlString xpLocale (toString x')
           _       -> return $ Locale [] [] [] [] []
 #else
   ls' <- getCachedLocale locale
